--- check_ssh.c.orig	2007-07-10 14:57:37.000000000 -0700
+++ check_ssh.c	2007-07-10 15:25:25.000000000 -0700
@@ -54,6 +54,7 @@
 int port = -1;
 char *server_name = NULL;
 char *remote_version = NULL;
+char *ssh_protocol = NULL;
 int verbose = FALSE;
 
 int process_arguments (int, char **);
@@ -110,6 +111,7 @@
 		{"timeout", required_argument, 0, 't'},
 		{"verbose", no_argument, 0, 'v'},
 		{"remote-version", required_argument, 0, 'r'},
+		{"ssh-protocol",required_argument,0,'s'},
 		{0, 0, 0, 0}
 	};
 
@@ -121,7 +123,7 @@
 			strcpy (argv[c], "-t");
 
 	while (1) {
-		c = getopt_long (argc, argv, "+Vhv46t:r:H:p:", longopts, &option);
+		c = getopt_long (argc, argv, "+Vhv46t:r:H:p:s:", longopts, &option);
 
 		if (c == -1 || c == EOF)
 			break;
@@ -154,9 +156,12 @@
 			usage4 (_("IPv6 support not available"));
 #endif
 			break;
-		case 'r':									/* remote version */
+		case 'r':									/* remote string version */
 			remote_version = optarg;
 			break;
+		case 's':									/* ssh protocol version */
+			ssh_protocol = optarg;
+                        break;
 		case 'H':									/* host */
 			if (is_host (optarg) == FALSE)
 				usage2 (_("Invalid hostname/address"), optarg);
@@ -250,10 +255,18 @@
 
 		if (remote_version && strcmp(remote_version, ssh_server)) {
 			printf
-				(_("SSH WARNING - %s (protocol %s) version mismatch, expected '%s'\n"),
+				(_("SSH WARNING - %s (protocol %s) version mismatch, expected server string '%s'\n"),
 				 ssh_server, ssh_proto, remote_version);
 			exit (STATE_WARNING);
 		}
+
+                if (ssh_protocol && strncmp(ssh_protocol, ssh_proto, strlen(ssh_protocol))) {
+                        printf
+                                (_("SSH WARNING - %s (protocol %s) version mismatch, expected protocol '%s'\n"),
+                                 ssh_server, ssh_proto, ssh_protocol);
+                        exit (STATE_WARNING);
+                }
+
 		
 		printf
 			(_("SSH OK - %s (protocol %s)\n"),
@@ -293,6 +306,9 @@
 	printf (" %s\n", "-r, --remote-version=STRING");
   printf ("    %s\n", _("Warn if string doesn't match expected server version (ex: OpenSSH_3.9p1)"));
 	
+       printf (" %s\n", "-s, --ssh-protocol=STRING");
+  printf ("    %s\n", _("Warn if minimum supported protocol doesn't match expected version (ex: 2.0)"));
+
 	printf (_(UT_VERBOSE));
 
 	printf (_(UT_SUPPORT));
@@ -304,6 +320,6 @@
 print_usage (void)
 {
   printf (_("Usage:"));
-	printf ("%s [-46] [-t <timeout>] [-r <remote version>] [-p <port>] <host>\n", progname);
+	printf ("%s [-46] [-t <timeout>] [-r <remote version>] [-s <ssh protocol>] [-p <port>] <host>\n", progname);
 }
 
